#!/bin/sh

#######################################################################
#
#		 Name:		 		 wmngplng.sh
#
#		 Created		 		 Bradley T. Gill
#		 		 		 IBM Software Services for Tivoli
#		 		 		 10/26/05
#
#		 Synopis:		 Should be scheduled by cron to run for the 
#		 		 		 duration of a distibution.  The interval
#		 		 		 should be set for 20 minutes
#
#######################################################################

### GLOBAL DECLARATIONS & DEFAULT ###

OS_TYPE=`uname -a | awk '{print $1}'`
if [ "X$OS_TYPE" = "XWindows_NT" ]
then
	. ${SystemRoot}/system32/drivers/etc/Tivoli/setup_env.sh 2>/dev/null
	InitFile="${SystemRoot}/system32/drivers/etc/Tivoli/wcfgplng.ini"
	TmpDir="c:/tmp/"
else
	. /etc/Tivoli/setup_env.sh 2>/dev/null
	InitFile="/etc/Tivoli/wcfgplng.ini"
	TmpDir="/tmp/"
fi
umask 0003

WorkDir="${TmpDir}PatchMgt/"
WebBase="${TmpDir}web/PatchMgt/"
LogFile="${TmpDir}wmngplng.log"
LogLevel=0
MailLevel=1
HTTPBase=""
MailList=""
UnavailAsActive=FALSE

ActiveLimit=100000
APM_rim="planner"
MDIST2_rim="mdist2"
query_lib_name='ACTIVITY_PLANNER_REPORTING'

# Temporary queries and files name
plan_info="ACTIVITY_PLANNER_REPORTING_PLAN_INFO"
act_info="ACTIVITY_PLANNER_REPORTING_ACTIVITY_INFO"
all_info="ACTIVITY_PLANNER_REPORTING_GLOBAL_INFO"

### FUNCTIONS ###

Clean_and_Exit()
{
	rm -f ${TmpDir}$plan_info.out ${TmpDir}$act_info.out ${TmpDir}$all_info.out \
		${TmpDir}wrunquery.out ${TmpDir}mail_sum.tmp ${pre}_last.states \
		${WorkDir}${pre}/detailsum.cur ${TmpDir}plan.tmp ${TmpDir}Message.out \
		${TmpDir}Error.msg ${TmpDir}Error.out ${TmpDir}Warning.out \
		${TmpDir}${pre}TTandOther.tmp

	if [ X$1 = X ] || [ X$1 = X0 ]
	then
		log_message $LOG_INFO "Succesful exit"
		exit 0
	else
		log_message $LOG_INFO "Unsuccesful exit with $1"
		exit $1
	fi
}

print_numbers_from_string()
{
	echo $@ | awk 'BEGIN {
		str=""
	}
	{
		for (i=1; i<=length($0); i++)
	        {
	                c=substr($0,i,1)
	                gsub(/[0-9]/,"",c)
	                if (length(c)==0)
	                {
	                        str=str substr($0,i,1)
	                }
       		}
	}
	END {
		if (length(str)==0)
			str=5
	        print str
	}'
}

number_of_lines()
{
	nlines=`awk 'END {
		print NR
	}' $1 2>/dev/null`

	if [ X$nlines = X ]
	then
		echo 0
	else
		echo $nlines
	fi
}

log_file()
{
	if [ $# -lt 2 ]
	then
		log_message $LOG_WARNING "No file ($@) passed to log_file..."
	else
		lev=`print_numbers_from_string $1`
		shift
		if [ $lev -le $LogLevel ]
		then
			unset data
			if [ $lev -eq 0 ]
			then
				data="`date \"+%Y/%m/%d %H:%M:%S\"` F:"
			fi
			if [ $lev -eq 1 ]
			then
				data="`date \"+%Y/%m/%d %H:%M:%S\"` E:"
			fi
			if [ $lev -eq 2 ]
			then
				data="`date \"+%Y/%m/%d %H:%M:%S\"` W:"
			fi
			if [ $lev -eq 3 ]
			then
				data="`date \"+%Y/%m/%d %H:%M:%S\"` I:"
			fi
			if [ "X$data" != X ]
			then
				awk -v data="$data" 'NR==1 {
					spazi = " "
					for (i=2; i<=length(data); i++)
						spazi = spazi " "
					print data, $0
				}
				NR>1 {
					print spazi, $0
				}' $1 >> $LogFile
			fi
		fi
	fi
}

log_message()
{
	if [ $# -lt 2 ]
	then
		log_message $LOG_WARNING "No message ($@) passed to log_message..."
	else
		lev=`print_numbers_from_string $1`
		shift
		if [ $lev -le $LogLevel ]
		then
			data=`date "+%Y/%m/%d %H:%M:%S"`
			if [ $lev -eq 0 ]
			then
				echo  "$data F: $@" >> $LogFile
			fi
			if [ $lev -eq 1 ]
			then
				echo  "$data E: $@" >> $LogFile
			fi
			if [ $lev -eq 2 ]
			then
				echo  "$data W: $@" >> $LogFile
			fi
			if [ $lev -eq 3 ]
			then
				echo  "$data I: $@" >> $LogFile
			fi
		fi
	fi
}

send_message()
{
	if [ $# -lt 2 ]
	then
		log_message $LOG_WARNING "No message ($@) passed to send_message..."
	else
		lev=$1
		shift
		Subject="Report from $this_script on `hostname`"
		if [ $lev -le $MailLevel ]
		then
			if [ X$1 != X ]
			then
				if [ X$1 = "X-s" ]
				then
					Subject=$2
					shift; shift
				fi
			fi

			File=$1; shift
			if [ "X$OS_TYPE" = "XWindows_NT" ]
			then
				msg=`awk -v subj="$Subject" 'BEGIN {
					str="Subject:" subj
				}
				{
					str=str "\n" $0
				}
				END {
					print str
				}' $File`
			fi
			for i in $MailList
			do
				if [ "X$OS_TYPE" = "XWindows_NT" ]
				then
					idlcall $ROOTADMIN send_support '"'"$i"'"' '"'"${msg}"'"'
				else
					mail -s "$Subject" $i < $File
				fi
			done
			if [ X$1 != X ]
			then
				Clean_and_Exit $1
			fi
		fi
	fi
}

subtract()
{
	echo "$1,$2" | awk -F, '{
		x = $1 - $2
		printf("%.2f", x)
	}'
}

divide()
{
	if [ "X$2" = X ] || [ $2 -eq 0 ]
	then
		echo 0
	else
		echo "$1,$2" | awk -F, '{
			x = $1 / $2
			printf("%.2f", x)
		}'
	fi
}

calc_percentage()
{
	if [ "X$2" = X ] || [ $2 -eq 0 ]
	then
		echo 0
	else
		echo "$1,$2" | awk -F, '{
			x = ($1*100) / $2
			printf("%.2f", x)
		}'
	fi
}

set_or_create_query()
{
	qq=$1; shift
	wgetquery $qq > ${TmpDir}getquery.out 2>/dev/null
	if [ $? -ne 0 ]
	then
		log_message $LOG_INFO "Query $qq not existing: creating..."

		qd=$1; shift
		qr=$1; shift
		qv=$1; shift

		if [ -e ${TmpDir}where_clause.in ]
		then
			wcrtquery -s -d "$qd" -r "$qr" -v "$qv" $@ "$query_lib_name" "$qq" < ${TmpDir}where_clause.in > ${TmpDir}Error.out 2>&1
			RC=$?
		else
			wcrtquery -d "$qd" -r "$qr" -v "$qv" $@ "$query_lib_name" "$qq" > ${TmpDir}Error.out 2>&1
			RC=$?
		fi

		if [ $RC -ne 0 ]
		then
			echo "Unable to create Query $qq in Query Library '$query_lib_name'" > ${TmpDir}Error.msg
			echo "Error message is:" >> ${TmpDir}Error.msg
			cat ${TmpDir}Error.out >> ${TmpDir}Error.msg
			log_file $LOG_ERROR ${TmpDir}Error.msg
			send_message $HIGH_IMPORTANCE ${TmpDir}Error.msg 1001
		fi
		log_message $LOG_INFO "Query $qq created"
	else
		log_message $LOG_INFO "Query $qq exists: check the where clause"
		rm -f ${TmpDir}where_clause.out
		where_lines=`awk -v outf="${TmpDir}where_clause.out" 'BEGIN {
			next_l=0
			nl=0
		}
		next_l==2 {
			print $0 >> outf
			nl++
		}
		next_l==1 {
			next_l++
		}
		$0~/^Where Clause:/ {
			next_l=1
		}
		END {
			print nl
		}' ${TmpDir}getquery.out`

		RC=0
		if [ ! -e ${TmpDir}where_clause.in ] && [ $where_lines -gt 0 ]
		then
			log_message $LOG_INFO "Removing the where clause"
			touch ${TmpDir}where_clause.in
			wsetquery -s $qq < ${TmpDir}where_clause.in > ${TmpDir}Error.out 2>&1
			RC=$?
		else
			if [ $where_lines -le 0 ]
			then
				log_message $LOG_INFO "Setting the where clause"
				wsetquery -s $qq < ${TmpDir}where_clause.in > ${TmpDir}Error.out 2>&1
				RC=$?
			else
				diff -bw ${TmpDir}where_clause.out ${TmpDir}where_clause.in >/dev/null 2>&1
				if [ $? -ne 0 ]
				then
					log_message $LOG_INFO "Changing the where clause"
					wsetquery -s $qq < ${TmpDir}where_clause.in > ${TmpDir}Error.out 2>&1
					RC=$?
				else
					log_message $LOG_INFO "Where clauses are identical"
				fi
			fi
		fi
		if [ $RC -ne 0 ]
		then
			echo "Unable to set the Where Clause of Query '$qq'" > ${TmpDir}Error.msg
			echo "Error message is:" >> ${TmpDir}Error.msg
			cat ${TmpDir}Error.out >> ${TmpDir}Error.msg
			log_file $LOG_ERROR ${TmpDir}Error.msg
			send_message $HIGH_IMPORTANCE ${TmpDir}Error.msg 1001
		fi
	fi
	rm -f ${TmpDir}Error.out ${TmpDir}Error.msg
}

get_apm_plan_info()
{

#	Queries the APM DB for the plans with name in the ${pre}_dist_pln.lst file.
#	Output in ${TmpDir}$plan_info.out

	rm -f ${TmpDir}wrunquery.out ${TmpDir}Error.out ${TmpDir}Error.msg ${TmpDir}where_clause.in

	n_plans=0
	not_submitted=0

	all_plans=`awk -F, -v api="'" -v w_file="${TmpDir}where_clause.in" 'BEGIN {
		printf "(NAME in (" > w_file
		first_clause = 1
		n_plan = 0;
		n_not_submit = 0;
	}
	$2=="Submitted" {
		if (first_clause == 0)
			printf "," api $3 api >> w_file
		else
		{
			first_clause = 0
			printf api $3 api >> w_file
		}
		n_plan++
	}
	$2=="Not_Submitted" {
		n_not_submit++
	}
	END {
		printf "))\n" >> w_file
		print n_plan,n_not_submit
	}' ${pre}_dist_pln.lst`

	nplans=`echo $all_plans | awk '{print $1}'`
	not_submitted=`echo $all_plans | awk '{print $2}'`

	if [ $nplans -gt 0 ]
	then
        	log_message $LOG_INFO "Creating or setting $plan_info query"
		set_or_create_query "$plan_info" "\"Plan INFO Query\"" "$APM_rim" "V_PLAN_STATUS" -c NAME -c PLAN_ID

		wrunquery -n -d, $plan_info > ${TmpDir}wrunquery.out 2>${TmpDir}Error.out
		if [ $? -ne 0 ]
		then
			echo "Unable to get APM Plan Info" > ${TmpDir}Error.msg
			echo "Error message is:" >> ${TmpDir}Error.msg
			cat ${TmpDir}Error.out >> ${TmpDir}Error.msg

		else
			sort ${TmpDir}wrunquery.out | awk -F, '$1!=prev {
				print $1 "," $2
				prev=$1
			}' > ${TmpDir}$plan_info.out

			nplans=`number_of_lines ${TmpDir}$plan_info.out`
			if [ $nplans -le 0 ]
			then
				echo "No plan found" > ${TmpDir}Error.msg
			fi
		fi
	else 
		if [ $not_submitted -le 0 ]
		then
	        	log_message $LOG_INFO  "The plan list file '${pre}_dist_pln.lst' contains only $not_submitted Not Submitted plans"
		fi
	fi

	if [ -e ${TmpDir}Error.msg ]
	then
		log_file $LOG_ERROR ${TmpDir}Error.msg
		send_message $HIGH_IMPORTANCE ${TmpDir}Error.msg 1002
	else
		log_message $LOG_INFO "Found $nplans plans"
	fi
}

get_apm_activity_info()
{

#	Queries the APM DB for the activities with plan_ID in the ${WorkDir}$plan_3yyinfo.out file.
#	The data are merged to contains also plans with no distributed activities.
#	Output in ${TmpDir}$act_info.out

	rm -f ${TmpDir}wrunquery.out ${TmpDir}Error.out ${TmpDir}Error.msg ${TmpDir}where_clause.in

	nplans=`awk -F, -v api="'" -v w_file="${TmpDir}where_clause.in" 'BEGIN {
		printf "(PLAN_ID in (" > w_file
		first_clause = 1
		n_plan=0
	}
	first_clause == 0 {
		n_plan++
		printf "," api $2 api >> w_file
	}
	first_clause == 1 {
		n_plan++
		printf api $2 api >> w_file
		first_clause = 0
	}
	END {
		printf "))\n" >> w_file
		print n_plan
	}' ${TmpDir}$plan_info.out`

	nacts=0

	if [ $nplans -gt 0 ]
	then
        	log_message $LOG_INFO "Creating or setting $act_info query"

		set_or_create_query "$act_info" "\"Activity INFO Query\"" "$APM_rim" "V_ACT_STATUS_EX" -c PLAN_ID -c NAME -c STATUS -c APPL_SPEC_ACT_ID

		wrunquery -n -d, $act_info > ${TmpDir}wrunquery.out 2>${TmpDir}Error.out
		if [ $? -ne 0 ]
		then
			echo "Unable to get APM Activity Info" > ${TmpDir}Error.msg
			echo "Error message is:" >> ${TmpDir}Error.msg
			cat ${TmpDir}Error.out >> ${TmpDir}Error.msg
		fi

		if [ -e ${TmpDir}wrunquery.out ]
		then
			nacts=`number_of_lines ${TmpDir}wrunquery.out`
		fi

		if [ $nacts -le 0 ]
		then
			echo "No activity info found in the APM database for plans:" > ${TmpDir}Warning.msg
			awk -F, '{
				lst = lst $3 " " 
			}
			END {
				print lst
			}' ${pre}_dist_pln.lst >> ${TmpDir}Warning.msg

		fi
	else
		echo "No plans found into ${TmpDir}$plan_info.out for plans:" > ${TmpDir}Warning.msg
		awk -F, '{
			lst = lst $3 " " 
		}
		END {
			print lst
		}' ${pre}_dist_pln.lst >> ${TmpDir}Warning.msg
	fi

	if [ -e {TmpDir}Error.msg ]
	then
		log_file $LOG_ERROR ${TmpDir}Error.msg
		send_message $HIGH_IMPORTANCE ${TmpDir}Error.msg 1003
	else
		if [ -e {TmpDir}Warning.msg ]
		then
			send_message $LOW_IMPORTANCE ${TmpDir}Warning.msg
			log_file $LOG_WARNING ${TmpDir}Warning.msg
		else
			log_message $LOG_INFO "Found $nacts activities"
		fi
	fi

	touch ${TmpDir}wrunquery.out
	awk -F, -v plan_file="${TmpDir}$plan_info.out" 'BEGIN {
		npl=0
		while ((getline < plan_file) >0)
		{
			plid[++npl]=$2
			plname[npl]=$1
			ifound[npl]=0
		}
	}
	{
		pln=""
		for (i=1; pln=="" && i<=npl; i++)
		{
			if ($1==plid[i])
			{
				pln=plname[i]
				ifound[i] = 1
			}
		}
		if (pln!="")
		{
			for (i=2; i<=4; i++)
			{
				if (length($i)==0)
					sub(//,"0",$i)
			}
			print pln "," $1 "," $2 "," $3 "," $4
		}
	}
	END {
		for (i=1; i<=npl; i++)
		{
			if (ifound[i] != 1)
				print plname[i] "," plid[i] ",0,0,0"
		}
	}' ${TmpDir}wrunquery.out > ${TmpDir}$act_info.out
}

get_all_info()
{

#	Queries the MDIST2 DataBase for DistID contained in ${WorkDir}${TmpDir}$act_info.out
#	The data is merged with the lines of ${WorkDir}${TmpDir}$act_info.out NOT having a DistID.
#	Output in ${WorkDir}${TmpDir}$all_info.out, containing:
#	plan_name,plan_id,activity_name,status,DistID,total_trgts,unavail_trgts,succes_trgts,failed_trgts,interrupted_trgts,waiting_trgts,completed_trgts

	rm -f ${TmpDir}wrunquery.out ${TmpDir}Error.out ${TmpDir}Error.msg ${TmpDir}where_clause.in

	nacts=`awk -F, -v api="'" -v w_file="${TmpDir}where_clause.in" 'BEGIN {
		printf "(ID in (" > w_file
		first_clause = 1
		n_act=0
	}
	first_clause == 0 && $5 != "" && $5 != "0" {
		n_act++
		printf "," api $5 api >> w_file
	}
	first_clause == 1 && $5 != "" && $5 != "0" {
		n_act++
		printf api $5 api >> w_file
		first_clause = 0
	}
	END {
		printf "))\n" >> w_file
		print n_act
	}' ${TmpDir}$act_info.out`

	if [ $nacts -gt 0 ]
	then
        	log_message $LOG_INFO "Creating or setting $all_info query"

		set_or_create_query "$all_info" "\"Mdist2 INFO Query\"" "$MDIST2_rim" "DIST_STATE"\
			-c ID \
			-c TARGET_COUNT \
			-c UNAVAILABLE_COUNT \
			-c SUCCESSFUL_COUNT \
			-c FAILED_COUNT \
			-c INTERRUPTED_COUNT \
			-c WAITING_COUNT \
			-c COMPLETED_COUNT

		wrunquery -n -d, $all_info > ${TmpDir}wrunquery.out 2>${TmpDir}Error.out
		if [ $? -ne 0 ]
		then
			echo "Unable to get MDIST2 Activity Info" > ${TmpDir}Error.msg
			echo "Error message is:" >> ${TmpDir}Error.msg
			cat ${TmpDir}Error.out >> ${TmpDir}Error.msg
        		log_file $LOG_ERROR cat ${TmpDir}Error.msg
			send_message $HIGH_IMPORTANCE ${TmpDir}Error.msg 1004
		fi
	else
		echo "No activity found into ${TmpDir}$act_info.out for plans:" > ${TmpDir}Warning.msg
		awk -F, '{
			lst = lst $3 " " 
		}
		END {
			print lst
		}' ${pre}_dist_pln.lst >> ${TmpDir}Warning.msg
		send_message $LOW_IMPORTANCE ${TmpDir}Warning.msg
		log_file $LOG_WARNING ${TmpDir}Warning.msg
	fi

	touch ${TmpDir}wrunquery.out
	awk -F, -v act_file="${TmpDir}$act_info.out" 'BEGIN {
		nac=0
		nac_noid=0
		while ((getline < act_file) >0)
		{
			if ($5!="0")
			{
				id[++nac]=$5
				acrow[nac]=$0
				ifound[nac]=0
			}
			else
			{
				acrow_noid[++nac_noid]=$0
			}
		}
	}
	{
		ac=""
		for (i=1; ac=="" && i<=nac; i++)
		{
			if ($1==id[i])
			{
				ac=acrow[i]
				ifound[i] = 1
			}
		}
		for (i=2; i<=8; i++)
		{
			if (length($i)==0)
				sub(//,"0",$i)
		}

		print ac "," $2 "," $3 "," $4 "," $5 "," $6 "," $7 "," $8
	}
	END {
		for (i=1; i<=nac; i++)
		{
			if (ifound[i] != 1)
				print acrow[i] ",0,0,0,0,0,0,0"
		}
		for (i=1; i<=nac_noid; i++)
		{
			print acrow_noid[i] ",0,0,0,0,0,0,0"
		}
	}' ${TmpDir}wrunquery.out | sort > ${TmpDir}$all_info.out
        log_message $LOG_INFO "Found `number_of_lines ${TmpDir}$all_info.out` lines in get_all_info"
}

create_base_index()
{
	for a in a
	do
		echo '<HEAD>'
		echo '<style>'
		echo 'h3{color: #ffffff}'
		echo '</style>'
		echo '<TITLE>Activity Planner Reporting</TITLE>'
		echo '</HEAD>'
		echo ''
		echo '<BODY>'
		echo '<table bgcolor="black" border="0" cellspacing="0" cellpadding="0" width="100%">'
		echo '<tr>'
		echo '<td><img src="./logo.gif"/></td>'
		echo '<td width="60%"><H3 align="center">Activity Planner Reporting</H3></td>'
		echo '<td><img src="./tivoli_banner.gif"/></td>'
		echo '</tr>'
		echo '</table>'
		echo ''
		echo '<BR>'
		echo ''
		echo '<table border="0" cellspacing="0" cellpadding="2" width="100%">'
		echo '<tr><th align="center"><FONT FACE="Sans Serif" COLOR="#000099" SIZE="5">Welcome to the Activity Planner</FONT></th></tr>'
		echo '<tr><th><FONT FACE="Sans Serif" COLOR="#000099" SIZE="5">Reporting Page</FONT></th></tr>'
		echo '</table>'
		echo '<hr width="100%" color="#000099" size="2">'
		echo ''
		echo '<BR>'
		echo '<BR>'
		echo '<BR>'
		echo ''
		echo '<table width=96% border="1" align="center">'
		echo '<tr><th colspan=4>Please Select a Distribution</th></tr>'
		echo "<tr><td align=center><a href=\"${HTTPBase}${pre}/index.html\">${pre} Distribution</td><td align=center>$now</td></tr>"
		echo '<!-- Insert new rows here -->'
		echo '</table>'
		echo ''
		echo '</BODY>'
	done > ${WebBase}index.html
}

check_or_add_slash()
{
	if [ X$1 != X ]
	then
		echo $1 | awk -F\/ '	$NF=="" {
						print $0
					}
					$NF!="" {
						print $0 "\/"
					}' 2>/dev/null
	else
		echo ""
	fi
}

### INITIALIZATION ###

this_script=`echo "$0" | awk -F\/ '{print $NF}' | awk -F\\\\ '{print $NF}'`

LOG_ERROR=1
LOG_WARNING=2
LOG_INFO=3
HIGH_IMPORTANCE=1
LOW_IMPORTANCE=2

if [ ! -e $InitFile ]
then
	log_message $LOG_INFO "Init file $InitFile not found; using defaults"
else
	. $InitFile > ${TmpDir}Error.msg 2>&1
	if [ `number_of_lines ${TmpDir}Error.msg` -gt 0 ] 
	then
		log_file $LOG_WARNING ${TmpDir}Error.msg
	fi
fi

TmpDir=`check_or_add_slash "$TmpDir"`
WorkDir=`check_or_add_slash "$WorkDir"`
WebBase=`check_or_add_slash "$WebBase"`
HTTPBase=`check_or_add_slash "$HTTPBase"`
UnavAct=`echo $UnavailAsActive |\
	awk '{
		c=substr(toupper($0),1,1)
		if (c=="T" || c=="Y" || $0=="1")
			print "1"
		else
			print "0"
	}'`

ALI=`wlookup TME_server`
ID=`objcall $ALI get_identity`
ROOTADMIN=`echo $ID | awk '{print $2}'` > ${TmpDir}Error.msg 2>&1
RC=$?
if [ "X$OS_TYPE" = "XWindows_NT" ]
then
	if [ $RC -ne 0 ] && [ "X$OS_TYPE" = "XWindows_NT" ]
	then
		log_message 0 "Error $RC getting the Tivoli Administrator: unable to send mails. The error text is:
		`cat ${TmpDir}Error.msg`"
		Clean_and_Exit 999
	fi
	if [ X$MailHost != X ]
	then
		wmailhost $MailHost
		log_message $LOG_INFO "Mail host set to $MailHost"
	else	
		MailHost=`wmailhost`
		if [ X$MailHost = X ]
		then
			echo  "No Mail Host: use the wmailhost command or set the MailHost variable in $InitFile" > ${TmpDir}Error.msg
	 		log_file $LOG_ERROR ${TmpDir}Error.msg
			send_message $HIGH_IMPORTANCE ${TmpDir}Error.msg 1000
		fi
	fi
fi

if [ $LogLevel -ge $LOG_INFO ]
then
	echo "Starting:" > ${TmpDir}Error.msg
	echo " - TmpDir   = $TmpDir" >> ${TmpDir}Error.msg
	echo " - WorkDir  = $WorkDir" >> ${TmpDir}Error.msg
	echo " - WebBase  = $WebBase" >> ${TmpDir}Error.msg
	echo " - HTTPBase = $HTTPBase" >> ${TmpDir}Error.msg
	if [ $UnavAct -eq 0 ]
	then
		echo "Unavailable and Interrupted targets will be considered NOT active" >> ${TmpDir}Error.msg
	else
		echo "Unavailable and Interrupted targets will be considered active" >> ${TmpDir}Error.msg
	fi
 	log_file $LOG_INFO ${TmpDir}Error.msg
fi

### MAIN ###

if [ ! -d $WorkDir ]
then
	 log_message $LOG_ERROR "Working directory $WorkDir not found: exiting"
	 echo  "Working directory $WorkDir not found: exiting" > ${TmpDir}Error.msg
	 log_file $LOG_ERROR ${TmpDir}Error.msg
	 send_message $HIGH_IMPORTANCE ${TmpDir}Error.msg 1
else
	 cd $WorkDir
fi
if [ $# -ne 1 ]
then
	 if [ -e msgs/error2.txt ]
	 then
		cat msgs/error2.txt > ${TmpDir}Error.msg
	 else
	 	echo  "No Base Name passed: exiting" > ${TmpDir}Error.msg
	 fi
	 log_file $LOG_ERROR ${TmpDir}Error.msg
	 send_message $HIGH_IMPORTANCE ${TmpDir}Error.msg 2
else
	 pre=$1
	 log_message $LOG_INFO "Distribution: $pre"  
fi

nplans=0
if [ -e ${WorkDir}${pre}_dist_pln.lst ]
then
	nplans=`number_of_lines ${WorkDir}${pre}_dist_pln.lst`
fi
if [ $nplans -le 0 ]
then
	if [ -e msgs/error3.txt ]
	then
		cat msgs/error3.txt > ${TmpDir}Error.msg
	else
		echo "Empty or not existing plans file list: ${WorkDir}${pre}_dist_pln.lst" > ${TmpDir}Error.msg
	fi
	log_file $LOG_ERROR ${TmpDir}Error.msg
	send_message $HIGH_IMPORTANCE ${TmpDir}Error.msg 3
fi

now=`date`
if [ ! -d ${WorkDir}${pre} ]
then
	 mkdir ${WorkDir}${pre}
	 echo "0:0:0" > ${WorkDir}${pre}/benchmarks
	 touch ${WorkDir}${pre}/detailsum.cur
	 touch ${WorkDir}${pre}/detailsum.tmp
fi
ThisWeb=${WebBase}$pre
if [ ! -e ${WorkDir}${pre}/benchmarks ]
then
	 echo "0:0:0" > ${WorkDir}${pre}/benchmarks
fi
lastrun=`cat ${WorkDir}${pre}/benchmarks |awk -F: '{print $1}'`
numruns=`cat ${WorkDir}${pre}/benchmarks |awk -F: '{print $3}'`
runbefore=`cat ${WorkDir}${pre}/benchmarks |awk -F: '{print $2}'`

nSubmittedPlans=0
get_apm_plan_info

if [ -e ${TmpDir}$plan_info.out ]
then
	nSubmittedPlans=`number_of_lines ${TmpDir}$plan_info.out`
fi
if [ $nSubmittedPlans -gt 0 ]
then
	get_apm_activity_info
	get_all_info
else
	rm -f ${TmpDir}$all_info.out
	touch ${TmpDir}$all_info.out
fi

base_just_created=0

if [ $nSubmittedPlans -gt 0 ]
then
	mkdir -p ${WebBase} 2>/dev/null
	if [ ! -e ${WebBase}index.html ]
	then
		log_message $LOG_INFO "Creating ${WebBase}index.html"
		create_base_index
		base_just_created=1
	fi

	if [ ! -d $ThisWeb ] || [ ! -e $ThisWeb/index.html ]
	then
			 mkdir -p $ThisWeb 2>/dev/null

			 if [ $base_just_created -eq 0 ]
			 then
				 while read line
				 do
					 echo $line |grep "Insert new rows here" 1>/dev/null

		 			 if [ $? -eq 0 ]
		 			 then
						 echo "<tr><td align=center><a href=\"${HTTPBase}${pre}/index.html\">${pre} Distribution</td><td align=center>$now</td></tr>" >> ${TmpDir}index.tmp
						 echo $line >> ${TmpDir}index.tmp
		 			 else
				 		 echo $line >> ${TmpDir}index.tmp
			 		 fi
			  	 done < ${WebBase}index.html
				 mv ${TmpDir}index.tmp ${WebBase}index.html  2>&1
	 		 fi

			 echo '<HEAD>' > $ThisWeb/index.html
			 echo '<style>' >> $ThisWeb/index.html
			 echo 'h3{color: #ffffff}' >> $ThisWeb/index.html
			 echo '</style>' >> $ThisWeb/index.html
			 echo '<TITLE>Activity Planner Reporting</TITLE>' >> index.html
			 echo '</HEAD>' >> $ThisWeb/index.html
			 echo '<BODY>' >> $ThisWeb/index.html
			 echo '<table bgcolor="black" border="0" cellspacing="0" cellpadding="0" width="100%">' >> $ThisWeb/index.html
			 echo '<tr>' >> $ThisWeb/index.html
			 echo "<td><img src=\"${HTTPBase}logo.gif\"/></td>" >> $ThisWeb/index.html
			 echo '<td width="60%"><H3 align="center">Activity Planner Reporting</H3></td>' >> $ThisWeb/index.html
			 echo "<td><img src=\"${HTTPBase}tivoli_banner.gif\"/></td>" >> $ThisWeb/index.html
			 echo '</tr>' >> $ThisWeb/index.html
			 echo '</table>' >> $ThisWeb/index.html
			 echo '<BR>' >> $ThisWeb/index.html

	 		 echo "<table border=\"0\" cellspacing=\"0\" cellpadding=\"2\" width=\"100%\"><tr><th align=\"center\"><FONT FACE=\"Sans Serif\" COLOR=\"#000099\" SIZE=\"5\">Welcome to the $pre Distribution</FONT></th></tr>" >> $ThisWeb/index.html
			 echo "<tr><th><FONT FACE=\"Sans Serif\" COLOR=\"#000099\" SIZE=\"5\">Reporting Page</FONT></th></tr></table>" >> $ThisWeb/index.html
		  	 echo "<hr width=\"100%\" color=\"#000099\" size=\"2\">" >> $ThisWeb/index.html
	 
		 	 echo "<BR><BR><BR>" >> $ThisWeb/index.html

			 echo "<table width=\"96%\" border=\"1\" align=\"center\"><tr><th colspan=4>Please Select a CheckPoint</th></tr>" >> $ThisWeb/index.html
	 		 echo "<tr><td align=center>Report 1</td><td align=center><a href=\"${HTTPBase}${pre}/report_Detail.html\">Detail</td>" >> $ThisWeb/index.html
	 		 echo "<td align=center><a href=\" ${HTTPBase}${pre}/report_Summary.html\">Summary</td><td align=center>$now</td></tr>" >> $ThisWeb/index.html
			 echo "<!-- Insert new rows here -->">> $ThisWeb/index.html
			 echo "</table>" >> $ThisWeb/index.html


	else
			 RN=`ls $ThisWeb | number_of_lines`
			 RN=`echo $RN |sed s/\ //g`
			 if [ $RN -eq 0 ]
			 then
			 		 RN=1
			 else
			 		 RN=$((RN+1))
			 		 RN=$((RN/2))
			 fi
			 while read line
			 do
			 		 echo $line |grep "Insert new rows here" 1>/dev/null
			 		 if [ $? -eq 0 ]
			 		 then
			 		 		 echo "<tr><td align=center>Report $RN</td><td align=center><a href=\"${HTTPBase}${pre}/report${RN}_Detail.html\">Detail</td>" >> ${TmpDir}index.tmp
			 		 		 echo "<td align=center><a href=\"${HTTPBase}${pre}/report${RN}_Summary.html\">Summary</td><td align=center>$now</td></tr>" >> ${TmpDir}index.tmp
			 		 		 echo $line >> ${TmpDir}index.tmp
			 		 else
			 		 		 echo $line >> ${TmpDir}index.tmp
			 		 fi
			 done < $ThisWeb/index.html
			 mv ${TmpDir}index.tmp $ThisWeb/index.html
			 
	fi
fi

if [ -e ${pre}_last.states ]
then
		 rm ${pre}_last.states
fi
if [ -e ${WorkDir}${pre}/detailsum.cur ]
then
		 rm ${WorkDir}${pre}/detailsum.cur
		 touch ${WorkDir}${pre}/detailsum.cur
else
		 touch ${WorkDir}${pre}/detailsum.cur
fi

if [ -e ${pre}_curr.states ]
then
		 mv ${pre}_curr.states ${pre}_last.states
else
		 touch ${pre}_last.states
fi
if [ -e ${TmpDir}${pre}_Unavailable.lst ]
then
		 rm ${TmpDir}${pre}_Unavailable.lst
fi
STT=0
STW=0
STU=0
STI=0
STS=0
SCount=0
STF=0
STC=0
STP=0
STPE=0
TAC=0

query_lib_name_obj=`wlookup -r QueryLibrary $query_lib_name 2> ${TmpDir}Error.out`
if [ $? -ne 0 ] || [ X$query_lib_name_obj = X ]
then
	echo "Unable to get Query Library $query_lib_name." > ${TmpDir}Error.msg
	echo "Error message is:" >> ${TmpDir}Error.msg
	cat ${TmpDir}Error.out >> ${TmpDir}Error.msg
	log_file $LOG_ERROR ${TmpDir}Error.msg
	send_message $HIGH_IMPORTANCE ${TmpDir}Error.msg 1011
fi

StillActive=0

if [ $nSubmittedPlans -gt 0 ]
then
	echo '<HEAD>' > $ThisWeb/report${RN}_Detail.html
	echo '<style>' >> $ThisWeb/report${RN}_Detail.html
	echo 'h3{color: #ffffff}' >> $ThisWeb/report${RN}_Detail.html
	echo '</style>' >> $ThisWeb/report${RN}_Detail.html
	echo '<TITLE>Activity Planner Reporting</TITLE>' >> $ThisWeb/report${RN}_Detail.html
	echo '</HEAD>' >> $ThisWeb/report${RN}_Detail.html
	echo '<BODY>' >> $ThisWeb/report${RN}_Detail.html
	echo '<table bgcolor="black" border="0" cellspacing="0" cellpadding="0" width="100%">' >> $ThisWeb/report${RN}_Detail.html
	echo '<tr>' >> $ThisWeb/report${RN}_Detail.html
	echo "<td><img src=\"${HTTPBase}logo.gif\"/></td>" >> $ThisWeb/report${RN}_Detail.html
	echo '<td width="60%"><H3 align="center">Activity Planner Reporting</H3></td>' >> $ThisWeb/report${RN}_Detail.html
	echo "<td><img src=\"${HTTPBase}tivoli_banner.gif\"/></td>" >> $ThisWeb/report${RN}_Detail.html
	echo '</tr>' >> $ThisWeb/report${RN}_Detail.html
	echo '</table>' >> $ThisWeb/report${RN}_Detail.html
	echo '<BR>' >> $ThisWeb/report${RN}_Detail.html

	echo '<table border="0" cellspacing="0" cellpadding="2" width="100%"><tr><TH width="100%" align="center"><FONT FACE="Sans Serif" COLOR="#000099" SIZE="5">APM Detail Reporting for '$pre' </FONT></TH></TR>' >> $ThisWeb/report${RN}_Detail.html
	echo '<TR><TD width="100%" align="right">'$now'</TD></tr></table>' >> $ThisWeb/report${RN}_Detail.html
	echo '<hr width="100%" color="#000099" size="2">' >> $ThisWeb/report${RN}_Detail.html
	echo '<BR><BR><BR>'       >> $ThisWeb/report${RN}_Detail.html

	echo '<HEAD>' > $ThisWeb/report${RN}_Summary.html
	echo '<style>' >> $ThisWeb/report${RN}_Summary.html
	echo 'h3{color: #ffffff}' >> $ThisWeb/report${RN}_Summary.html
	echo '</style>' >> $ThisWeb/report${RN}_Summary.html
	echo '<TITLE>Activity Planner Reporting</TITLE>' >> $ThisWeb/report${RN}_Summary.html
	echo '</HEAD>' >> $ThisWeb/report${RN}_Summary.html
	echo '<BODY>' >> $ThisWeb/report${RN}_Summary.html
	echo '<table bgcolor="black" border="0" cellspacing="0" cellpadding="0" width="100%">' >> $ThisWeb/report${RN}_Summary.html
	echo '<tr>' >> $ThisWeb/report${RN}_Summary.html
	echo "<td><img src=\"${HTTPBase}logo.gif\"/></td>" >> $ThisWeb/report${RN}_Summary.html
	echo '<td width="60%"><H3 align="center">Activity Planner Reporting</H3></td>' >> $ThisWeb/report${RN}_Summary.html
	echo "<td><img src=\"${HTTPBase}tivoli_banner.gif\"/></td>" >> $ThisWeb/report${RN}_Summary.html
	echo '</tr>' >> $ThisWeb/report${RN}_Summary.html
	echo '</table>' >> $ThisWeb/report${RN}_Summary.html
	echo '<BR>' >> $ThisWeb/report${RN}_Summary.html

	echo '<table border="0" cellspacing="0" cellpadding="2" width="100%"><tr><TH width="100%" align="center"><FONT FACE="Sans Serif" COLOR="#000099" SIZE="5">APM Summary Reporting for '$pre'</FONT></TH></tr>' >> $ThisWeb/report${RN}_Summary.html
	echo '<TR><TD width="100%" align="right">'$now'</TD></tr></table>' >> $ThisWeb/report${RN}_Summary.html
	echo '<hr width="100%" color="#000099" size="2">' >> $ThisWeb/report${RN}_Summary.html
	echo '<BR><BR><BR>'       >> $ThisWeb/report${RN}_Summary.html

	echo '<table width="96%" border="1" align="center">' >> $ThisWeb/report${RN}_Summary.html
	echo '<tr><th colspan=11 bgcolor=red><FONT color=white>Summary Report for '$pre' Distribution at '$now'</th></tr>' >> $ThisWeb/report${RN}_Summary.html
	echo '<tr>' >> $ThisWeb/report${RN}_Summary.html
	echo '<th>Plan Name</th><th>Packages</th><th>Completed</th><th>Interrupted</th><th>Waiting</th><th>Unavail</th>' >> $ThisWeb/report${RN}_Summary.html
	echo '<th>Distributed</th><th>Active</th><th>Failed</th><th>Effective</th><th>Complete</th><tr>' >> $ThisWeb/report${RN}_Summary.html
fi
TotalActsTargs=0
TT=0
export TT
rm -f ${TmpDir}plan.tmp
while read line
do
		 plan=`echo $line |awk -F, '{print $1}'`
		 state=`echo $line |awk -F, '{print $2}'`
		 SubPlan=`echo $line |awk -F, '{print $3}'`
		 AllActsTargs=`echo $line |awk -F, '{print $4}'`
		 PlanTargs=`echo $line |awk -F, '{print $5}'`
		 TotalActsTargs=$((TotalActsTargs+AllActsTargs))
		 if [ $StillActive -ge $ActiveLimit ] && [ $state == Not_Submitted ]
		 then
	 		 log_message $LOG_WARNING "Active targets ($StillActive) over the limit ($ActiveLimit); plan $plan not submitted"
	 		 echo $line >> ${TmpDir}plan.tmp
	 		 continue
		 fi
		 
		 if [ $state = Not_Submitted ] && [ $StillActive -lt $ActiveLimit ] 
		 then
	 		 log_message $LOG_INFO "Trying to submit $plan"
	 		 wsubpln -r $plan > ${TmpDir}plan.out 2>&1
        		 grep -i Success ${TmpDir}plan.out >/dev/null
        		 if [ $? -eq 0 ]
        		 then
                		 SubPlan=`grep -i Success ${TmpDir}plan.out |awk -F\" '{print $2}'`
                		 state=Submitted
 		 		 StillActive=$((StillActive+AllActsTargs))
                		 echo "${plan},${state},${SubPlan},${AllActsTargs},${PlanTargs}" >> ${TmpDir}plan.tmp
				 if [ -e msgs/submitted ]
				 then
					cat msgs/submitted > ${TmpDir}msg.out
				 else
					echo "Plan succesfully submitted" > ${TmpDir}msg.out
				 fi
				 log_file $LOG_INFO ${TmpDir}msg.out
		 		 send_message $HIGH_IMPORTANCE -s "$plan" ${TmpDir}msg.out
                		 continue
        		 else
				 if [ -e msgs/error4.txt ]
				 then
					cat msgs/error4.txt > ${TmpDir}msg.out
				 else
					echo "Error submitting the plan ${plan}:" > ${TmpDir}msg.out
				 fi
				 cat ${TmpDir}plan.out >> ${TmpDir}msg.out
				 log_file $LOG_ERROR ${TmpDir}msg.out
				 send_message $HIGH_IMPORTANCE ${TmpDir}msg.out
				 state=Error
				 echo "${plan},${state},${SubPlan},${AllActsTargs},${PlanTargs}" >> ${TmpDir}plan.tmp
        		 fi
			 continue
		 fi
		 
		 if [ $state = Error ]
		 then
	 		 echo $line >> ${TmpDir}plan.tmp
		 	 continue
		 fi
 
		 if [ $state = Submitted ]
		 then
	 		 echo '<table width="96%" border="1" align="center">' >> $ThisWeb/report${RN}_Detail.html
	 		 echo "<tr><th colspan=12 bgcolor=red><FONT color=white>$SubPlan</th></tr>" >> $ThisWeb/report${RN}_Detail.html
	 		 echo '<tr>' >> $ThisWeb/report${RN}_Detail.html
	 		 echo '<th>Activity Name</th><th>State</th><th>Dist ID</th><th>Packages</th><th>Completed</th><th>Interrupted</th><th>Waiting</th><th>Unavail</th>' >> $ThisWeb/report${RN}_Detail.html
	 		 echo '<th>Distributed</th><th>Failed</th><th>Effective</th><th>Complete</th><tr>' >> $ThisWeb/report${RN}_Detail.html
	 		 
	 		 TT=0
	 		 TU=0
	 		 TS=0
	 		 TW=0
	 		 TI=0
	 		 Count=0
	 		 TF=0
	 		 TC=0
	 		 TP=0
	 		 TPE=0
	 		 
			 echo "Getting Activities for plan '$SubPlan'" > ${TmpDir}Message.out
	 		 awk -F, -v plan="$SubPlan" '{if ($1==plan) {print $4,$5,$6,$7,$8,$9,$10,$11,$12,$3}}' ${TmpDir}$all_info.out |\
	 		 while read state ID Targ Unav Succ Fail Interup Waiting Cnum Activity
	 		 do
					 echo "- '$Activity', ID '$ID', state '$state', Targets $Targ, Completed $Cnum, Succesfull $Succ, Failed $Fail, Interrupted $Interup, Waiting $Waiting" >> ${TmpDir}Message.out
	 		 		 if [ "X$ID" != "X0" ]
	 		 		 then

	 		 		 		 Count=$((Count+1))
	 		 		 		 TmpID=`echo $ID |awk -F. '{print $2}'`

	 		 		 		 TT=$((TT+Targ))
	 		 		 		 TU=$((TU+Unav))
	 		 		 		 if [ $TU -gt 0 ]
	 		 		 		 then
	 		 		 		 		 wmdist -e $ID UNAVAILABLE >> ${TmpDir}${pre}_Unavailable.lst
	 		 		 		 fi
	 		 		 		 TI=$((TI+Interup))
	 		 		 		 TW=$((TW+Waiting))
	 		 		 		 TS=$((TS+Succ))
	 		 		 		 TF=$((TF+Fail))
	 
	 		 		 		 TC=$((TC+Cnum))
	 		 		 		 Avail=$((Targ - Unav))
	 		 		 		 Etmp=$((Succ * 100))
	 		 		 		 		 
	 		 		 else
	 		 		 		 Activity='Not_Submitted'
	 		 		 		 ID=0
	 		 		 		 Targ=0
	 		 		 		 Cnum=0
	 		 		 		 Unav=0
	 		 		 		 Succ=0
	 		 		 		 Fail=0
	 		 		 		 Waiting=0
	 		 		 		 Interup=0
	 		 		 		 Effv=0
	 		 		 		 Cpct=0%
	 		 		 fi
	 		 		 		 
	 		 		 # Effv=$((Etmp / Cnum))
	 		 		 # The above line was replaced with the latter to reflcect decimals
	 		 		 Effv=`divide $Etmp $Cnum`
	 		 		 Cpct=`calc_percentage $Cnum $Targ`
	 		 		 ID=`echo $ID |awk -F. '{print $2}'`
	 		 		 echo "<tr><td align=center>$Activity</td><td align=center>$state</td><td align=center>$ID</td><td align=center>$Targ</td><td align=center>$Cnum</td><td align=center>$Interup</td><td align=center>$Waiting</td><td align=center>$Unav</td><td align=center>$Succ</td><td align=center>$Fail</td><td align=center>${Effv}%</td><td align=center>${Cpct}%</td></tr>" >> $ThisWeb/report${RN}_Detail.html
	 		 		 ActLine=`cat ${WorkDir}${pre}/detailsum.cur |grep ${Activity}`
	 		 		 if [ $? -eq 0 ] 
	 		 		 then
	 		 		 		 SDT=`echo $ActLine |awk -F\, '{print $2}'`
	 		 		 		 SDC=`echo $ActLine |awk -F\, '{print $3}'`
	 		 		 		 SDW=`echo $ActLine |awk -F\, '{print $4}'`
	 		 		 		 SDI=`echo $ActLine |awk -F\, '{print $5}'`
	 		 		 		 SDU=`echo $ActLine |awk -F\, '{print $6}'`
	 		 		 		 SDS=`echo $ActLine |awk -F\, '{print $7}'`
	 		 		 		 SDF=`echo $ActLine |awk -F\, '{print $8}'`
	 		 		 		 SDT=$((SDT+Targ))
	 		 		 		 SDC=$((SDC+Cnum))
	 		 		 		 SDW=$((SDW+Waiting))
	 		 		 		 SDI=$((SDI+Interup))
	 		 		 		 SDU=$((SDU+Unav))
	 		 		 		 SDS=$((SDS+Succ))
	 		 		 		 SDF=$((SDF+Fail))
	 		 		 else
	 		 		 		 SDT=$Targ
	 		 		 		 SDC=$Cnum
	 		 		 		 SDW=$Waiting
	 		 		 		 SDI=$Interup
	 		 		 		 SDU=$Unav
	 		 		 		 SDS=$Succ
	 		 		 		 SDF=$Fail
	 		 		 fi
	 		 		 cat ${WorkDir}${pre}/detailsum.cur |grep -v ${Activity} > ${WorkDir}${pre}/detailsum.tmp
	 		 		 echo "$Activity,$SDT,$SDC,$SDW,$SDI,$SDU,$SDS,$SDF" >> ${WorkDir}${pre}/detailsum.tmp
	 		 		 mv ${WorkDir}${pre}/detailsum.tmp ${WorkDir}${pre}/detailsum.cur
	 		 		 echo "$TT,$TI,$TW,$TU,$TS,$TF,$TC,$Count" > ${TmpDir}${pre}TTandOther.tmp
	 		 		 
	 		 done
			 log_file $LOG_INFO ${TmpDir}Message.out
	 		 TT=`awk -F\, '{print $1}' ${TmpDir}${pre}TTandOther.tmp`
	 		 TI=`awk -F\, '{print $2}' ${TmpDir}${pre}TTandOther.tmp`
	 		 TW=`awk -F\, '{print $3}' ${TmpDir}${pre}TTandOther.tmp`
	 		 TU=`awk -F\, '{print $4}' ${TmpDir}${pre}TTandOther.tmp`
	 		 TS=`awk -F\, '{print $5}' ${TmpDir}${pre}TTandOther.tmp`
	 		 TF=`awk -F\, '{print $6}' ${TmpDir}${pre}TTandOther.tmp`
	 		 TC=`awk -F\, '{print $7}' ${TmpDir}${pre}TTandOther.tmp`
	 		 Count=`awk -F\, '{print $8}' ${TmpDir}${pre}TTandOther.tmp`

	  		 SCount=$((SCount+1))
	  		 STT=$((STT+TT))
	  		 STI=$((STI+TI))
	  		 STW=$((STW+TW))
	  		 STU=$((STU+TU))
	  		 STS=$((STS+TS))
	  		 STF=$((STF+TF))
	  		 STC=$((STC+TC))
	  
	  		 if [ $Count -eq 0 ] || [ $TS -eq 0 ] || [ $TC -eq 0 ]
	  		 then
				TPE=0
				TP=0
	  		 else
  		 		 #TPE=$((TPE / Count))
  		 		 # The above line was replaced with the latter to reflect decimals
 		 		 TPE=`calc_percentage $TS $TC`

  		 		 #TP=$((TP / Count))
  		 		 # The above line was replaced with the latter to reflect decimals
 		 		 TP=`calc_percentage $TC $TT`
	  		 fi

	  		 if [ $UnavAct -eq 0 ]
			 then
	  		 	TAC=$((TT-TU-TC-TI))
			 else
	  		 	TAC=$((TT-TC))
			 fi

	  		 echo "<tr><th colspan=3><FONT color=blue>Totals</th><th><FONT color=blue>$TT</th><th><FONT color=blue>$TC</th><th><FONT color=blue>$TI</th><th><FONT color=blue>$TW</th><th><FONT color=blue>$TU</th><th><FONT color=blue>$TS</th><th><FONT color=blue>$TF</th><th><FONT color=blue>${TPE}%</th><th><FONT color=blue>${TP}%</th></tr>" >> $ThisWeb/report${RN}_Detail.html
	  		 echo "<tr><th>$SubPlan</th><td align=center>$TT</td><td align=center>$TC</td><td align=center>$TI</td><td align=center>$TW</td><td align=center>$TU</td><td align=center>$TS</td><td align=center>$TAC</td><td align=center>$TF</td><td align=center>${TPE}%</td><td align=center>${TP}%</td></tr>" >> $ThisWeb/report${RN}_Summary.html
	  		 echo "$SubPlan,$TT,$TC,$TI,$TW,$TU,$TS,$TF,$TPE,$TP,$TAC," >> ${pre}_curr.states
	  		 last=`cat ${pre}_last.states |grep "$SubPlan" 2>/dev/null`
	  		 if [ $? -eq 0 ]
	  		 then
	  		 		 LTT=`echo $last |awk -F, '{print $2}'`
	  		 		 LTC=`echo $last |awk -F, '{print $3}'`
	  		 		 LTI=`echo $last |awk -F, '{print $4}'`
	  		 		 LTW=`echo $last |awk -F, '{print $5}'`
	  		 		 LTU=`echo $last |awk -F, '{print $6}'`
	  		 		 LTS=`echo $last |awk -F, '{print $7}'`
	  		 		 LTF=`echo $last |awk -F, '{print $8}'`
	  		 		 LTPE=`echo $last |awk -F, '{print $9}'`
	  		 		 LTP=`echo $last |awk -F, '{print $10}'`
	  		 		 LTAC=`echo $last |awk -F, '{print $11}'`
	  		 		 echo "<tr><td align=center colspan=3>Last Report</td><td align=center>$LTT</td><td align=center>$LTC</td><td align=center>$LTI</td><td align=center>$LTW</td><td align=center>$LTU</td><td align=center>$LTS</td><td align=center>$LTF</td><td align=center>${LTPE}%</td><td align=center>${LTP}%</td></tr>" >> $ThisWeb/report${RN}_Detail.html
	 		 		 DifPE=`subtract $TPE $LTPE`
	 		 		 DifP=`subtract $TP $LTP`
	  		 		 echo "<tr><th align=center colspan=3><FONT color=red>Difference</th><th align=center><FONT color=red>$((TT-LTT))</th><th align=center><FONT color=red>$((TC-LTC))</th><th align=center><FONT color=red>$((TI-LTI))</th><th align=center><FONT color=red>$((TW-LTW))</th><th align=center><FONT color=red>$((TU-LTU))</th><th align=center><FONT color=red>$((TS-LTS))</th><th align=center><FONT color=red>$((TF-LTF))</th><th align=center><FONT color=red>${DifPE}%</th><th align=center><FONT color=red>${DifP}%</th></tr>" >> $ThisWeb/report${RN}_Detail.html
	  		 else
	  		 		 echo "<tr><td align=center colspan=3>No Historical Data</td><td align=center>0</td><td align=center>0</td><td align=center>0</td><td align=center>0</td><td align=center>0</td><td align=center>0</td><td align=center>0</td><td align=center>0%</td><td align=center>0%</td></tr>" >> $ThisWeb/report${RN}_Detail.html
	  		 		 echo "<tr><th colspan=3>Difference</th><th>$TT</th><th>$TC</th><th>$TI</th><th>$TW</th><th>$TU</th><th>$TS</th><th>$TF</th><th>${TPE}%</th><th>${TP}%</th></tr>" >> $ThisWeb/report${RN}_Detail.html
	  		 fi
	 		 echo "</table>" >> $ThisWeb/report${RN}_Detail.html
			 echo $line >> ${TmpDir}plan.tmp
		 fi
		 StillActive=$((StillActive+TAC))
done < ${WorkDir}${pre}_dist_pln.lst

if [ $STT -eq 0 ]
then
		 SuccPct=0
		 STP=0
else
 		 SuccPct=`calc_percentage $STC $STT`
fi

if [ $STC -eq 0 ]
then
		 EffPct=0
else
 		 EffPct=`calc_percentage $STS $STC`
fi

if [ $UnavAct -eq 0 ]
then
	STAC=$((STT-STU-STC-STI))
else
	STAC=$((STT-STC))
fi
LSTC=0
if [ $nSubmittedPlans -gt 0 ]
then
	echo "<tr><th><FONT color=blue>Current</th><th><FONT color=blue>$STT</th><th><FONT color=blue>$STC</th><th><FONT color=blue>$STI</th><th><FONT color=blue>$STW</th><th><FONT color=blue>$STU</th><th><FONT color=blue>$STS</th><th><FONT color=blue>$STAC</th><th><FONT color=blue>$STF</th><th><FONT color=blue>${EffPct}%</th><th><FONT color=blue>${SuccPct}%</th></tr>" >> $ThisWeb/report${RN}_Summary.html
	if [ -e ${pre}_summary.states ]
	then
			 last=`cat ${pre}_summary.states`
			 LSTT=`echo $last |awk -F, '{print $1}'`
			 LSTC=`echo $last |awk -F, '{print $2}'`
			 LSTI=`echo $last |awk -F, '{print $3}'`
			 LSTW=`echo $last |awk -F, '{print $4}'`
			 LSTU=`echo $last |awk -F, '{print $5}'`
			 LSTS=`echo $last |awk -F, '{print $6}'`
			 LSTF=`echo $last |awk -F, '{print $7}'`
			 LSTPE=`echo $last |awk -F, '{print $8}'`
			 LSTP=`echo $last |awk -F, '{print $9}'`
			 LSTAC=`echo $last |awk -F, '{print $10}'`
			 echo "<tr><th>Last Report</th><td align=center>$LSTT</td><td align=center>$LSTC</td><td align=center>$LSTI</td><td align=center>$LSTW</td><td align=center>$LSTU</td><td align=center>$LSTS</td><td align=center>$LSTAC</td><td align=center>$LSTF</td><td align=center>${LSTPE}%</td><td align=center>${LSTP}%</td></tr>" >> $ThisWeb/report${RN}_Summary.html
	 		 DifSTPE=`subtract $EffPct $STPE`
	 		 DifSTP=`subtract $SuccPct $LSTP`
			 echo "<tr><th><FONT color=red>Difference</th><th><FONT color=red>$((STT-LSTT))</th><th><FONT color=red>$((STC-LSTC))</th><th><FONT color=red>$((STI-LSTI))</th><th><FONT color=red>$((STW-LSTW))</th><th><FONT color=red>$((STU-LSTU))</th><th><FONT color=red>$((STS-LSTS))</th><th><FONT color=red>$((STAC-LSTAC))</th><th><FONT color=red>$((STF-LSTF))</th><th><FONT color=red>${DifSTPE}%</th><th><FONT color=red>${DifSTP}%</th></tr>" >> $ThisWeb/report${RN}_Summary.html
	else
			 echo "<tr><th>No Historical Data</th><td align=center>0</td><td align=center>0</td><td align=center>0</td><td align=center>0</td><td align=center>0</td><td align=center>0</td><td align=center>0</td><td align=center>0</td><td align=center>0%</td><td align=center>0%</td></tr>" >> $ThisWeb/report${RN}_Summary.html
			 echo "<tr><th>Difference</th><th>$STT</th><th>$STC</th><th>$STI</th><th>$STW</th><th>$STU</th><th>$STS</th><th>$STAC</th><th>$STF</th><th>${STPE}%</th><th>${STP}%</th></tr>" >> $ThisWeb/report${RN}_Summary.html
	fi
	DST=$((STC-LSTC))
	CurrAvg=$((DST*3))
	HourAvg=$((DST+lastrun+runbefore))

	if [ $numruns -eq 0 ]
	then
			 SumAvg=0
	else
			 SumAvg=$((STC/numruns*3))
	fi

	CTP=`calc_percentage $STC $TotalActsTargs`
	CUS=$((TotalActsTargs-STT))
	echo "<tr><td align=center colspan=10></td><tr>" >> $ThisWeb/report${RN}_Summary.html
	echo "<tr><th></th><th>Packages</th><th>Submitted</th><th>Not Submitted</th><th>Completed</th><th>Current Rate</th><th>Hour Rate</th><th>Campaign Rate</th><th>Complete</th></tr>" >> $ThisWeb/report${RN}_Summary.html
	echo "<tr><th><FONT color=blue>Campaign Total</th><th><FONT color=blue>$TotalActsTargs</th><th><FONT color=blue>$STT</th><th><FONT color=blue>$CUS</th><th><FONT color=blue>$STC</th><th><FONT color=blue>${CurrAvg}/hr</th><th><FONT color=blue>${HourAvg}/hr</th><th><FONT color=blue>${SumAvg}/hr</th><th><FONT color=blue>${CTP}%</th></tr>" >> $ThisWeb/report${RN}_Summary.html
	echo "$STT,$STC,$STI,$STW,$STU,$STS,$STF,$EffPct,$SuccPct,$STAC," > ${pre}_summary.states
	echo "<tr><td align=center colspan=10></td><tr>" >> $ThisWeb/report${RN}_Summary.html
	echo "<tr><th colspan=10 bgcolor=blue><FONT color=white>Summary Report by Activity</th><tr>" >> $ThisWeb/report${RN}_Summary.html
	echo "<tr><th>Activity Name</th><th>Targets</th><th>Completed</th><th>Interrupted</th><th>Waiting</th><th>Unavailable</th><th>Success</th><th>Failed</th><th>Effective Pct</th><th>Complete Pct</th><tr>" >> $ThisWeb/report${RN}_Summary.html
	while read line
	do
			 Act=`echo $line |awk -F\, '{print $1}'`
			 SDT=`echo $line |awk -F\, '{print $2}'`
			 SDC=`echo $line |awk -F\, '{print $3}'`
			 SDI=`echo $line |awk -F\, '{print $4}'`
			 SDW=`echo $line |awk -F\, '{print $5}'`
			 SDU=`echo $line |awk -F\, '{print $6}'`
			 SDS=`echo $line |awk -F\, '{print $7}'`
			 SDF=`echo $line |awk -F\, '{print $8}'`
			 SDCPct=`calc_percentage $SDC $SDT`
			 EffPct=`calc_percentage $SDS $SDC`
			 echo "<tr><th>$Act</th><td align=center>$SDT</td><td align=center>$SDC</td><td align=center>$SDW</td><td align=center>$SDI</td><td align=center>$SDU</td><td align=center>$SDS</td><td align=center>$SDF</td><th>${EffPct}%</th><th>${SDCPct}%</th><td align=center></td></tr>" >> $ThisWeb/report${RN}_Summary.html
	done < ${WorkDir}${pre}/detailsum.cur

	echo "</table>" >> $ThisWeb/report${RN}_Summary.html
	echo "</BODY>" >> $ThisWeb/report${RN}_Summary.html

	numruns=$((numruns+1))
	echo "$((DST)):$lastrun:$numruns" > ${WorkDir}${pre}/benchmarks

	echo "Summary Report for Distribution ${pre} at ${now}" > ${TmpDir}mail_sum.tmp
	echo "" >> ${TmpDir}mail_sum.tmp
	echo "Completed:    $STC" >> ${TmpDir}mail_sum.tmp
	echo "Current Rate: $CurrAvg" >> ${TmpDir}mail_sum.tmp
	echo "Hour Avg:     $HourAvg" >> ${TmpDir}mail_sum.tmp
	echo "Campaign Avg: $SumAvg" >> ${TmpDir}mail_sum.tmp
	echo "Percent Comp: ${CTP}%" >> ${TmpDir}mail_sum.tmp
	send_message $HIGH_IMPORTANCE ${TmpDir}mail_sum.tmp

else
	echo "Only plan submissions; no Summary Report generated for ${pre} at ${now}" > ${TmpDir}mail_sum.tmp
	send_message $LOW_IMPORTANCE ${TmpDir}mail_sum.tmp
fi
log_file $LOG_INFO ${TmpDir}mail_sum.tmp

if [ -e ${TmpDir}plan.tmp ]
then
	cp ${TmpDir}plan.tmp ${WorkDir}${pre}_dist_pln.lst
	rm ${TmpDir}plan.tmp
fi

Clean_and_Exit 0
